@@ -42,13 +42,6 @@ namespace Oxygen
         Helper( config )
     { init(); }
 
-    //______________________________________________________________________________
-    #if OXYGEN_USE_KDE4
-    StyleHelper::StyleHelper( const QByteArray& name ):
-        Helper( name )
-    { init(); }
-    #endif
-
     //______________________________________________________________________________
     void StyleHelper::invalidateCaches( void )
     {
